coords method

Area coords(
  1. List<num> coordsList, {
  2. bool? removeIf,
})

The coords attribute details the coordinates of the shape attribute in size, shape, and placement of an <area>. Read more...

Implementation

Area coords(List<num> coordsList, {bool? removeIf}) {
  if (removeIf != true && node.attrs != null) {
    VirtualAttr attr = VirtualAttr('coords', _html.listToCommas(coordsList));
    node.attrs!.add(attr);
  }
  return this;
}